launcherEF = {};

function launcherEF.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function launcherEF.registerEventListeners(vehicleType)
	local functionNames = { "onLoad", "onUpdate", "onDelete", "onLeaveVehicle"}

	for i, v in ipairs(functionNames) do
		SpecializationUtil.registerEventListener(vehicleType, v, launcherEF)
	end
end

function launcherEF:onLoad(savegame)
    self.EF = {}
	self.EF.launcherPS = {}
	ParticleUtil.loadParticleSystem(self.xmlFile, self.EF.launcherPS, "vehicle.motorized.exhaustEffects.launcherPS", self.components, false, nil, self.baseDirectory)
	self.EF.launcherPSEmitTime = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.motorized.exhaustEffects.launcherPS#launcherPSEmitTime"), 1.0) * 10
	
	self.EF.startPS = {}
	ParticleUtil.loadParticleSystem(self.xmlFile, self.EF.startPS, "vehicle.motorized.exhaustEffects.motorStartPS", self.components, false, nil, self.baseDirectory)
	self.EF.motorStartPSDuration = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.motorized.exhaustEffects.motorStartPS#motorStartPSDuration"), 1.0) * 11.5
	self.EF.motorStartPSDelay = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.motorized.exhaustEffects.motorStartPS#motorStartPSDelay"), 1.0) * 11.5
	
end;

function launcherEF:onUpdate(dt, isActiveForInput, isActiveForInputIgnoreSelection, isSelected)
	
	local launchPSenableTime = (self.spec_motorized.motorStartTime - self.spec_motorized.motorStartDuration)
	local launchPSEmitDisable = launchPSenableTime + (self.EF.launcherPSEmitTime);
	
	local motorStartPSDelay = (self.EF.motorStartPSDelay);
	local startPSEnableTime = (self.spec_motorized.motorStartTime - self.spec_motorized.motorStartDuration) + motorStartPSDelay;
	local startPSDisableTime = startPSEnableTime + (self.EF.motorStartPSDuration);
	
	if self.isClient then
		if self:getIsActive() and self.spec_motorized.isMotorStarted then
			if (g_currentMission.time <= launchPSEmitDisable and g_currentMission.time >= launchPSenableTime ) then
				ParticleUtil.setEmittingState(self.EF.launcherPS, true);
			else
				ParticleUtil.setEmittingState(self.EF.launcherPS, false);
			end;
			if (g_currentMission.time <= startPSDisableTime and g_currentMission.time >= startPSEnableTime ) then
				ParticleUtil.setEmittingState(self.EF.startPS, true);
			else
				ParticleUtil.setEmittingState(self.EF.startPS, false);
			end;
		end;
	end;
end;

function launcherEF:onDelete()
	if self.EF.launcherPS ~= nil then
		ParticleUtil.deleteParticleSystem(self.EF.launcherPS);
	end;
	if self.EF.startPS ~= nil then
		ParticleUtil.deleteParticleSystem(self.EF.startPS);
	end;
end;
function launcherEF:onLeaveVehicle()
	if self.EF.launcherPS then
		ParticleUtil.setEmittingState(self.EF.launcherPS, false);
	end;
	if self.EF.startPS then
		ParticleUtil.setEmittingState(self.EF.startPS, false);
	end;
end;